EngineBridge class

Resolves, spawns, and communicates with the Go engine binary.

Constructors

EngineBridge({required void onMessage(EngineMessage), bool verbose = false})

Properties

enginePath String
Resolves the path to the engine binary.
no setter
hashCode int
The hash code for this object.
no setterinherited
onMessage → void Function(EngineMessage)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(BlueprintConfig config, String targetDir, {bool dryRun = false}) Future<bool>
Sends an apply or plan command to the engine.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited