PlanItemMessage class

Inheritance

Constructors

PlanItemMessage({required String id, required String action, required String path, required String pack})
const

Properties

action String
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
pack String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited