BlueprintConfig class

Constructors

BlueprintConfig({required String name, required String org, String outputDir = '.', required ArchitectureConfig architecture, required StateManagementConfig stateManagement, required RoutingConfig routing, required APIConfig api, required FeaturesConfig features, required BuildConfig build, required CodegenConfig codegen, required TestingConfig testing, required CIConfig ci})
const
BlueprintConfig.defaults({required String name, required String org})
Default config with sensible values.
factory
BlueprintConfig.fromYaml(Map yaml)
Deserialize from a YAML map.
factory

Properties

api APIConfig
final
architecture ArchitectureConfig
final
build BuildConfig
final
ci CIConfig
final
codegen CodegenConfig
final
features FeaturesConfig
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
org String
final
outputDir String
final
routing RoutingConfig
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement StateManagementConfig
final
testing TestingConfig
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serialize to a JSON-compatible map for IPC with the Go engine.
toString() String
A string representation of this object.
inherited
toYaml() String
Serialize to YAML string for saving blueprint.yaml.

Operators

operator ==(Object other) bool
The equality operator.
inherited