RoutingConfig class

Constructors

RoutingConfig({required String package, required bool deepLinks, List<String> schemes = const [], List<String> hosts = const []})
const
RoutingConfig.fromYaml(Map m)
factory

Properties

final
hashCode int
The hash code for this object.
no setterinherited
hosts List<String>
final
package String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited