TestingConfig class
Constructors
- TestingConfig({required bool unit, required bool widget, required bool integration})
-
const
- TestingConfig.fromYaml(Map m)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- integration → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit → bool
-
final
- widget → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited